diff --git a/Library/Homebrew/dependency_collector.rb b/Library/Homebrew/dependency_collector.rb
index e11be462d0fea1dfcae78222c917745404d8d72f..378e12cbbe25facf76872ed8ce2661b833907f0d 100644
--- a/Library/Homebrew/dependency_collector.rb
+++ b/Library/Homebrew/dependency_collector.rb
@@ -70,7 +70,7 @@ class DependencyCollector
     elsif (tag = tags.first) && LANGUAGE_MODULES.include?(tag)
       # Next line only for legacy support of `depends_on 'module' => :python`
       # It should be replaced by `depends_on :python => 'module'`
-      return PythonInstalled.new("2", spec, *tags) if tag == :python
+      return PythonInstalled.new("2", spec) if tag == :python
       LanguageModuleDependency.new(tag, spec)
     else
       Dependency.new(spec, tags)
@@ -99,8 +99,8 @@ class DependencyCollector
     when :clt        then CLTDependency.new(tags)
     when :arch       then ArchRequirement.new(tags)
     when :hg         then MercurialDependency.new(tags)
-    when :python, :python2 then PythonInstalled.new("2", *tags)
-    when :python3    then PythonInstalled.new("3", *tags)
+    when :python, :python2 then PythonInstalled.new("2", tags)
+    when :python3    then PythonInstalled.new("3", tags)
     # Tiger's ld is too old to properly link some software
     when :ld64       then LD64Dependency.new if MacOS.version < :leopard
     else
diff --git a/Library/Homebrew/requirements/python_dependency.rb b/Library/Homebrew/requirements/python_dependency.rb
index 0c182b66b493ba5a4151fb426e5ae993c856a68b..3130d1c771f4e7c0dc17004d21c185c68321b9cd 100644
--- a/Library/Homebrew/requirements/python_dependency.rb
+++ b/Library/Homebrew/requirements/python_dependency.rb
@@ -31,15 +31,16 @@ class PythonInstalled < Requirement
     end
   end
 
-  def initialize(version="2.6", *tags )
-    # Extract the min_version if given. Default to python 2.X else
-    if /(\d+\.)*\d+/ === version.to_s
-      @min_version = PythonVersion.new(version)
+  def initialize(default_version="2.6", tags=[] )
+    tags = [tags].flatten
+    # Extract the min_version if given. Default to default_version else
+    if /(\d+\.)*\d+/ === tags.first.to_s
+      @min_version = PythonVersion.new(tags.shift)
     else
-      raise "Invalid version specification for Python: '#{version}'"
+      @min_version = PythonVersion.new(default_version)
     end
 
-    # often used idiom: e.g. sipdir = "share/sip" + python.if3then3
+    # often used idiom: e.g. sipdir = "share/sip#{python.if3then3}"
     if @min_version.major == 3
       @if3then3 = "3"
     else
@@ -56,7 +57,7 @@ class PythonInstalled < Requirement
     @imports = {}
     tags.each do |tag|
       if tag.kind_of? String
-        @imports[tag] = tag
+        @imports[tag] = tag  # if the module name is the same as the PyPi name
       elsif tag.kind_of? Hash
         @imports.merge!(tag)
       end